using System;
using Server.Targeting;
using Server.Network;
using Server.Mobiles;

namespace Server.Spells.Magician
{
	public class ShockingGraspSpell : MagicianSpell
	{
		private static SpellInfo m_Info = new SpellInfo(
				"Shocking Grasp", "Shrik Merse",
				Reagent.MandrakeRoot,
				Reagent.Bloodmoss
			);
		public override string Desc{ get{ return "Imbues your hands with a powerful electrical charge."; } } 
		public override string ReagentsDesc{ get{ return "One MandakeRoot, Bloodmoss."; } }
        public override SpellCircle SpellLevel { get { return SpellCircle.First; } }
        public override int SpellNumber { get { return 339; } }
		public override double CastDelay{ get{ return 2.0; } }
		public override double RequiredSkill{ get{ return 10.0; } }
		public override int RequiredMana{ get{ return 10; } }
		
		public override SpellSchool SpellSchool{ get{ return SpellSchool.Evocation; } }

		public ShockingGraspSpell( Mobile caster, Item scroll ) : base( caster, scroll, m_Info )
		{
		}
		
		public override void OnCast()
		{
			Caster.Target = new InternalTarget( this );
		}

		public override bool DelayedDamage{ get{ return true; } }

		public void Target( Mobile m )
		{
			if ( !Caster.CanSee( m ) )
			{
				Caster.SendLocalizedMessage( 500237 ); // Target can not be seen.
			}
			else if ( CheckHSequence( m ) )
			{
				Mobile source = Caster;

				SpellHelper.Turn( source, m );

				SpellHelper.CheckReflect( (int)this.SpellLevel, ref source, ref m );

				int damage = Utility.Random( 4, 4 );

				m.FixedParticles( 0x37DF, 9, 12, 5030, EffectLayer.Waist );
				source.PlaySound( 0x29 );
				
				Caster.DoHarmful( m );
				//damage = AbsorbDamage(m, ResistType.Energy, damage);
				m.Damage( damage );
			}

			FinishSequence();
		}

		private class InternalTarget : Target
		{
			private ShockingGraspSpell m_Owner;

			public InternalTarget( ShockingGraspSpell owner ) : base( 12, false, TargetFlags.Harmful )
			{
				m_Owner = owner;
			}

			protected override void OnTarget( Mobile from, object o )
			{
				if ( o is Mobile )
				{
					m_Owner.Target( (Mobile)o );
				}
			}

			protected override void OnTargetFinish( Mobile from )
			{
				m_Owner.FinishSequence();
			}
		}
	}
}
