using System;
using Server.Targeting;
using Server.Network;

namespace Server.Spells.Magician
{
	public class HoldPersonSpell : MagicianSpell
	{
		private static SpellInfo m_Info = new SpellInfo(
				"Hold Person", "Norto Hinrae",
				Reagent.MandrakeRoot,
				Reagent.MandrakeRoot,
				Reagent.SpidersSilk
			);

		public override string Desc{ get{ return "Freezes a target humanoid."; } } 
		public override string ReagentsDesc{ get{ return "Two MandrakeRoot, one SpiderSilk."; } }
        public override SpellCircle SpellLevel { get { return SpellCircle.Third; } }
        public override int SpellNumber { get { return 332; } }
 		public override double CastDelay{ get{ return 2.0; } }
		public override double RequiredSkill{ get{ return 15.0; } }
		public override int RequiredMana{ get{ return 10; } }
	
		public override SpellSchool SpellSchool{ get{ return SpellSchool.Conjuration; } }
	
		public HoldPersonSpell( Mobile caster, Item scroll ) : base( caster, scroll, m_Info )
		{
		}

		public override void OnCast()
		{
			Caster.Target = new InternalTarget( this );
		}

		public void Target( Mobile m )
		{
			if ( !Caster.CanSee( m ) )
			{
				Caster.SendLocalizedMessage( 500237 ); // Target can not be seen.
			}
			else if ( Core.AOS && (m.Frozen || m.Paralyzed || (m.Spell != null && m.Spell.IsCasting)) )
			{
				Caster.SendLocalizedMessage( 1061923 ); // The target is already frozen.
			}
			else if ( CheckHSequence( m ) )
			{
				SpellHelper.Turn( Caster, m );

				SpellHelper.CheckReflect( (int)this.SpellLevel, Caster, ref m );

				double duration;

                duration = 60; //1 minute duration			

				m.Paralyze( TimeSpan.FromSeconds( duration ) );

				m.PlaySound( 0x204 );
				m.FixedEffect( 0x376A, 6, 1 );
			}

			FinishSequence();
		}

		public class InternalTarget : Target
		{
			private HoldPersonSpell m_Owner;

			public InternalTarget( HoldPersonSpell owner ) : base( 12, false, TargetFlags.Harmful )
			{
				m_Owner = owner;
			}

			protected override void OnTarget( Mobile from, object o )
			{
				if ( o is Mobile )
					m_Owner.Target( (Mobile)o );
			}

			protected override void OnTargetFinish( Mobile from )
			{
				m_Owner.FinishSequence();
			}
		}
	}
}
