using System;
using System.Collections;
using Server.Targeting;
using Server.Network;
using Server.Misc;
using Server.Items;
using Server.Mobiles;

namespace Server.Spells.Magician
{
	public class FireSphereSpell : MagicianSpell
	{
		private static SpellInfo m_Info = new SpellInfo(
				"Fire Sphere", "Lor Flam Gin",
				Reagent.SpidersSilk,
				Reagent.SulfurousAsh,
				Reagent.SulfurousAsh,
				Reagent.SulfurousAsh,
				Reagent.SulfurousAsh,
				Reagent.Citrine
			);
		public override string Desc{ get{ return "Creates a circle of fire around the caster."; } } 
		public override string ReagentsDesc{ get{ return "One Spider's Silk, One Citrine, Four SulfurousAsh."; } }
        public override SpellCircle SpellLevel { get { return SpellCircle.Seventh; } }
        public override int SpellNumber { get { return 357; } }
		public override double CastDelay{ get{ return 2.0; } }
		public override double RequiredSkill{ get{ return 60.0; } }
		public override int RequiredMana{ get{ return 35; } }
		public override SpellSchool SpellSchool{ get{ return SpellSchool.Evocation; } }
		public FireSphereSpell( Mobile caster, Item scroll ) : base( caster, scroll, m_Info )
		{
		}
		public override void OnCast()
		{
			if ( SpellHelper.CheckTown( Caster.Location, Caster ) && CheckSequence() )
			{
				Effects.PlaySound( Caster.Location, Caster.Map, 0x20C );
				int itemID = 0x19AB;
				int i = 1;
				TimeSpan duration = TimeSpan.FromSeconds( 4.0 );
				Point3D loc1 = new Point3D( Caster.X + 1 , Caster.Y , Caster.Z );
				Point3D loc2 = new Point3D( Caster.X + 2 , Caster.Y , Caster.Z );
				Point3D loc3 = new Point3D( Caster.X , Caster.Y + 1 , Caster.Z );
				Point3D loc4 = new Point3D( Caster.X , Caster.Y + 2 , Caster.Z );
				Point3D loc5 = new Point3D( Caster.X - 1 , Caster.Y , Caster.Z );
				Point3D loc6 = new Point3D( Caster.X - 2 , Caster.Y , Caster.Z );
				Point3D loc7 = new Point3D( Caster.X , Caster.Y - 1 , Caster.Z );
				Point3D loc8 = new Point3D( Caster.X , Caster.Y - 2 , Caster.Z );
				Point3D loc9 = new Point3D( Caster.X - 1 , Caster.Y - 1 , Caster.Z );
				Point3D loc10 = new Point3D( Caster.X + 1 , Caster.Y + 1 , Caster.Z );
				Point3D loc11 = new Point3D( Caster.X - 1 , Caster.Y + 1 , Caster.Z );
				Point3D loc12 = new Point3D( Caster.X + 1 , Caster.Y - 1 , Caster.Z );
				new InternalItem( itemID, loc1, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc2, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc3, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc4, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc5, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc6, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc7, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc8, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc9, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc10, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc11, Caster, Caster.Map, duration, i );
				new InternalItem( itemID, loc12, Caster, Caster.Map, duration, i );
			}
			FinishSequence();
		}

		[DispellableField]
		private class InternalItem : Item
		{
			private Timer m_Timer;
			private DateTime m_End;
			private Mobile m_Caster;

			public override bool BlocksFit{ get{ return true; } }

			public InternalItem( int itemID, Point3D loc, Mobile caster, Map map, TimeSpan duration, int val ) : base( itemID )
			{
				bool canFit = SpellHelper.AdjustField( ref loc, map, 12, false );

				Visible = false;
				Movable = false;
				Light = LightType.Circle300;

				MoveToWorld( loc, map );

				m_Caster = caster;

				m_End = DateTime.Now + duration;

				m_Timer = new InternalTimer( this, TimeSpan.FromSeconds( Math.Abs( val ) * 0.2 ), caster.InLOS( this ), canFit );
				m_Timer.Start();
			}

			public override void OnAfterDelete()
			{
				base.OnAfterDelete();

				if ( m_Timer != null )
					m_Timer.Stop();
			}

			public InternalItem( Serial serial ) : base( serial )
			{
			}

			public override void Serialize( GenericWriter writer )
			{
				base.Serialize( writer );

				writer.Write( (int) 1 ); // version

				writer.Write( m_Caster );
				writer.WriteDeltaTime( m_End );
			}

			public override void Deserialize( GenericReader reader )
			{
				base.Deserialize( reader );

				int version = reader.ReadInt();

				switch ( version )
				{
					case 1:
					{
						m_Caster = reader.ReadMobile();

						goto case 0;
					}
					case 0:
					{
						m_End = reader.ReadDeltaTime();

						m_Timer = new InternalTimer( this, TimeSpan.Zero, true, true );
						m_Timer.Start();

						break;
					}
				}
			}

			public override bool OnMoveOver( Mobile m )
			{
				if ( Visible && m_Caster != null && SpellHelper.ValidIndirectTarget( m_Caster, m ) && m_Caster.CanBeHarmful( m, false ) )
				{
					int damage = 10;

					//damage = AbsorbDamage(m, ResistType.Fire, damage);

					m_Caster.DoHarmful( m );
					m.Damage( damage );
					m.PlaySound( 0x208 );
				}

				return true;
			}

			private class InternalTimer : Timer
			{
				private InternalItem m_Item;
				private bool m_InLOS, m_CanFit;

				private static Queue m_Queue = new Queue();

				public InternalTimer( InternalItem item, TimeSpan delay, bool inLOS, bool canFit ) : base( delay, TimeSpan.FromSeconds( 1.0 ) )
				{
					m_Item = item;
					m_InLOS = inLOS;
					m_CanFit = canFit;

					Priority = TimerPriority.FiftyMS;
				}

				protected override void OnTick()
				{
					if ( m_Item.Deleted )
						return;

					if ( !m_Item.Visible )
					{
						if ( m_InLOS && m_CanFit )
							m_Item.Visible = true;
						else
							m_Item.Delete();

						if ( !m_Item.Deleted )
						{
							m_Item.ProcessDelta();
							Effects.SendLocationParticles( EffectItem.Create( m_Item.Location, m_Item.Map, EffectItem.DefaultDuration ), 0x376A, 9, 10, 5029 );
						}
					}
					else if ( DateTime.Now > m_Item.m_End )
					{
						m_Item.Delete();
						Stop();
					}
					else
					{
						Map map = m_Item.Map;
						Mobile caster = m_Item.m_Caster;

						if ( map != null && caster != null )
						{
							foreach ( Mobile m in m_Item.GetMobilesInRange( 0 ) )
							{
								if ( (m.Z + 16) > m_Item.Z && (m_Item.Z + 12) > m.Z && SpellHelper.ValidIndirectTarget( caster, m ) && caster.CanBeHarmful( m, false ) )
									m_Queue.Enqueue( m );
							}

							while ( m_Queue.Count > 0 )
							{
								Mobile m = (Mobile)m_Queue.Dequeue();

								int damage = 150;

								m.PlaySound( 0x208 );
								
								caster.DoHarmful( m );
								//damage = AbsorbDamage(m, ResistType.Fire, damage);
								m.Damage( damage );
							}
						}
					}
				}
			}
		}
	}
}

